@@ -34,11 +34,6 @@
 #include "yelp-info.h"
 #include "yelp-base.h"
 
-typedef struct {
-	YelpBase    *base;
-	GtkTreeIter *parent;
-} ForeachData;
-
 struct _YelpBasePriv {
 	GNode  *toc_tree;
 
@@ -46,7 +41,6 @@ struct _YelpBasePriv {
 	GSList *windows;
 };
 
-
 static void           yelp_base_init                (YelpBase       *base);
 static void           yelp_base_class_init          (YelpBaseClass  *klass);
 static void           yelp_base_new_window_cb       (YelpWindow     *window,
